from pydantic import Field
from koil import koilable
from koil.composition import Composition
from unlok.rath import UnlokRath


@koilable(add_connectors=True)
class Unlok(Composition):
    rath: UnlokRath = Field(default_factory=UnlokRath)



from kuay.rath import KuayRath
from koil.composition import Composition
from pydantic import Field

from lok.rath import ManRath


class Man(Composition):
    rath: ManRath = Field(default_factory=ManRath)
